@@ -41,9 +41,9 @@
 #ifndef MPD_DB_H
 #define MPD_DB_H
 
-#include <mpd/connection.h>
-#include <mpd/tag.h>
-#include <mpd/compiler.h>
+#include "connection.h"
+#include "tag.h"
+#include "compiler.h"
 
 #include <stdbool.h>
 #include <time.h>
@@ -199,19 +199,62 @@ mpd_search_add_modified_since_constraint(struct mpd_connection *connection,
 					 enum mpd_operator oper,
 					 time_t value);
 
+/**
+ * Add an expression string.
+ *
+ * @param connection a #mpd_connection
+ * @param expression the expression string; must be enclosed in
+ * parantheses
+ * @return true on success, false on error
+ *
+ * @since libmpdclient 2.15, MPD 0.21
+ */
+bool
+mpd_search_add_expression(struct mpd_connection *connection,
+			  const char *expression);
+
+/**
+ * Group the results by the specified tag.
+ *
+ * @param connection a #mpd_connection
+ * @param type the tag type to group by
+ * @return true on success, false on error
+ *
+ * @since libmpdclient 2.12, MPD 0.19
+ */
+bool
+mpd_search_add_group_tag(struct mpd_connection *connection,
+			 enum mpd_tag_type type);
+
+/**
+ * Sort the results by the specified named attribute.
+ *
+ * @param connection a #mpd_connection
+ * @param name the attribute name to sort with; can be a tag name or
+ * "Last-Modified"
+ * @param descending sort in reverse order?
+ * @return true on success, false on error
+ *
+ * @since MPD 0.21, libmpdclient 2.15
+ */
+bool
+mpd_search_add_sort_name(struct mpd_connection *connection,
+			 const char *name, bool descending);
+
 /**
  * Sort the results by the specified tag.
  *
  * @param connection a #mpd_connection
  * @param type the tag type to sort with
- * @param reserved must be false
+ * @param descending sort in reverse order?
  * @return true on success, false on error
  *
- * @since libmpdclient 2.11
+ * @since MPD 0.21, libmpdclient 2.11; #descending since libmpdclient
+ * 2.15
  */
 bool
 mpd_search_add_sort_tag(struct mpd_connection *connection,
-			enum mpd_tag_type type, bool reserved);
+			enum mpd_tag_type type, bool descending);
 
 /**
  * Request only a portion of the result set.
